@@ -117,7 +117,13 @@ run(RawArgs) ->
 -spec run_aux(rebar_state:t(), [string()]) ->
     {ok, rebar_state:t()} | {error, term()}.
 run_aux(State, RawArgs) ->
-    io:setopts([{encoding, unicode}]),
+    %% The shell is already set to Unicode from Erlang/OTP 26+.
+    %% Skipping this also avoids a regression on Erlang/OTP 26.0.0.
+    case code:ensure_loaded(prim_tty) of
+      {module, _} -> ok;
+      {error, _} -> io:setopts([{encoding, unicode}])
+    end,
+
     %% Profile override; can only support one profile
     State1 = case os:getenv("REBAR_PROFILE") of
                  false ->
@@ -128,7 +134,13 @@ run_aux(State, RawArgs) ->
                      rebar_state:apply_profiles(State, [list_to_atom(Profile)])
              end,
 
-    rebar_utils:check_min_otp_version(rebar_state:get(State1, minimum_otp_vsn, undefined)),
+    MinimumOTPVsn = rebar_state:get(State1, minimum_otp_vsn, undefined),
+    App0 = rebar_state:current_app(State1),
+    App = case App0 of
+              undefined -> undefined;
+              _ -> rebar_app_info:name(App0)
+          end,
+    rebar_utils:check_min_otp_version(MinimumOTPVsn, App),
     rebar_utils:check_blacklisted_otp_versions(rebar_state:get(State1, blacklisted_otp_vsns, undefined)),
 
     %% Maybe change the default hex CDN
@@ -300,7 +312,12 @@ log_level() ->
                 Di when Di == false; Di == "" ->
                     case os:getenv("DEBUG") of
                         D when D == false; D == "" ->
-                            rebar_log:default_level();
+                            try
+                                {ok, L} = application:get_env(rebar, log_level),
+                                 rebar_log:atom_to_level(L)
+                            catch
+                                _:_ -> rebar_log:default_level()
+                            end;
                         _ ->
                             rebar_log:debug_level()
                     end;
