@@ -42,7 +42,7 @@
 -define(DEPS, [compile]).
 
 -dialyzer({nowarn_function, rewrite_leaders/2}).
--dialyzer({nowarn_function, start_interactive/0}).
+-dialyzer({nowarn_function, start_interactive/1}).
 
 %% ===================================================================
 %% Public API
@@ -82,10 +82,10 @@ init(State) ->
                          "relx apps if not specified."},
                         {relname, $r, "relname", atom,
                          "Name of the release to use as a template for the "
-                         "shell session"},
+                         "shell session."},
                         {relvsn, $v, "relvsn", string,
                          "Version of the release to use for the shell "
-                         "session"},
+                         "session."},
                         {start_clean, undefined, "start-clean", boolean,
                          "Cancel any applications in the 'apps' list "
                          "or release."},
@@ -93,12 +93,16 @@ init(State) ->
                          "Path to file of os environment variables to setup "
                          "before expanding vars in config files."},
                         {user_drv_args, undefined, "user_drv_args", string,
-                         "Arguments passed to user_drv start function for "
-                         "creating custom shells."},
+                         "For versions of Erlang prior to 26, this option "
+                         "can be used to pass arguments to the user_drv start "
+                         "function for creating custom shells. Starting "
+                         "with Erlang 26, the arguments defined with this "
+                         "option are applied to the shell start_interactive "
+                         "function."},
                         {eval, undefined, "eval", string,
-                         "Erlang term(s) to execute after the apps have been
-                          started, but before the shell is presented to the 
-                          user"}
+                         "Erlang term(s) to execute after the apps have been "
+                         "started, but before the shell is presented to the "
+                         "user."}
                     ]}
             ])
     ),
@@ -129,8 +133,8 @@ format_error(Reason) ->
 shell(State) ->
     setup_name(State),
     setup_paths(State),
-    ShellArgs = debug_get_value(shell_args, rebar_state:get(State, shell, []), undefined,
-                                "Found user_drv args from command line option."),
+    ShellArgs = debug_get_value(shell_args, rebar_state:get(State, shell, []), [],
+                                "Found shell args from command line option or plugin."),
     setup_shell(ShellArgs),
     maybe_run_script(State),
     %% apps must be started after the change in shell because otherwise
@@ -168,11 +172,11 @@ setup_shell(ShellArgs) ->
             rewrite_leaders(OldUser, NewUser),
             maybe_reset_logger(LoggerState);
         true ->
-            ok = start_interactive()
+            ok = start_interactive(ShellArgs)
     end.
 
-start_interactive() ->
-    shell:start_interactive().
+start_interactive(ShellArgs) ->
+    apply(shell, start_interactive, ShellArgs).
 
 %% @private starting with OTP-21.2.3, there's an oddity where the logger
 %% likely tries to handle system logs while we take down the TTY, which
@@ -222,7 +226,7 @@ setup_new_shell(ShellArgs) ->
     _ = supervisor:terminate_child(kernel_sup, user),
     %% start a new shell (this also starts a new user under the correct group)
     case ShellArgs of
-        undefined ->
+        [] ->
             _ = user_drv:start();
         _ ->
             _ = user_drv:start(ShellArgs)
@@ -357,7 +361,8 @@ simulate_proc_lib() ->
 
 maybe_run_eval(State) ->
     Exprs = find_evals_to_run(State),
-    lists:map(fun(Expr) ->
+    lists:map(fun(Expr0) ->
+        Expr = maybe_append_dot(Expr0),
         ?INFO("Evaluating: ~p",[Expr]),
         {ok, _} = eval(Expr)
     end, Exprs).
@@ -382,6 +387,15 @@ eval(Expression) ->
             end
     end.
 
+maybe_append_dot(Expression) ->
+    case re:run(Expression, "\\.\\s*$", [{capture, none}, unicode]) of
+        nomatch ->
+            ?DEBUG("Appending missing '.' to the end of ~p",[Expression]),
+            Expression ++ ".";
+        match ->
+            Expression
+    end.
+
 setup_name(State) ->
     {Long, Short, Opts} = rebar_dist_utils:find_options(State),
     rebar_dist_utils:either(Long, Short, Opts).
@@ -660,7 +674,7 @@ maybe_set_env_vars(State) ->
         {error, _} ->
             ?WARN("Failed to read file with environment variables: ~p", [EnvFile1]);
         {ok, Bin} ->
-            Lines = string:split(unicode:characters_to_list(Bin), "\n", all),
+            Lines = re:split(unicode:characters_to_list(Bin), "\n|\r\n", [{return, list}]),
             [handle_env_var_line(Line) || Line <- Lines]
     end.
 
